OC.L10N.register(
    "core",
    {
    "Please select a file." : "Изаберите фајл.",
    "File is too big" : "Фајл је превелик",
    "The selected file is not an image." : "Изабрани фајл није слика.",
    "The selected file cannot be read." : "Није могуће читати изабрани фајл.",
    "The file was uploaded" : "Фајл је отпремљен",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Фајл за отпремање премашује upload_max_filesize директиву у php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Отпремани фајл превазилази смерницу MAX_FILE_SIZE наведену у ХТМЛ обрасцу",
    "The file was only partially uploaded" : "Фајл је парцијално отпремљен",
    "No file was uploaded" : "Није отпремљен фајл",
    "Missing a temporary folder" : "Недостаје привремена фасцикла",
    "Could not write file to disk" : "Не могу да упишем фајл на диск",
    "A PHP extension stopped the file upload" : "ПХП екстензија је зауставила отпремање фајла",
    "Invalid file provided" : "Понуђени фајл није исправан",
    "No image or file provided" : "Нису понуђени ни слика ни фајл",
    "Unknown filetype" : "Непознат тип фајла",
    "An error occurred. Please contact your admin." : "Дошло је до грешке. Контактирајте администратора.",
    "Invalid image" : "Неисправна слика",
    "No temporary profile picture available, try again" : "Нема привремене слике профила. Покушајте поново",
    "No crop data provided" : "Нема података о опсецању",
    "No valid crop data provided" : "Нема исправних података о опсецању",
    "Crop is not square" : "Опсецање није квадратног облика",
    "State token does not match" : "Стање жетона се не слаже",
    "Invalid app password" : "Неисправна апликативна лозинка",
    "Could not complete login" : "Не могу да довршим пријављивање",
    "State token missing" : "Недостаје жетон стања",
    "Your login token is invalid or has expired" : "Ваш жетон за пријављивање је неисправан или је истекао",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Ово Nextcloud издање заједнице није подржано и брза обавештења су ограничена.",
    "Login" : "Пријава",
    "Please try again" : "Молимо вас да покушате поново",
    "Password reset is disabled" : "Ресетовање лозинке није омогућено",
    "Could not reset password because the token is expired" : "Лозинка није могла да се ресетује јер је истекао жетон",
    "Could not reset password because the token is invalid" : "Лозинка није могла да се ресетује јер жетон не важи",
    "Password is too long. Maximum allowed length is 469 characters." : "Лозинка је сувише дугачка. Дозвољено је највише 469 знакова.",
    "%s password reset" : "%s лозинка ресетована",
    "Password reset" : "Ресетовање лозинке",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Кликните следеће дугме за ресетовање лозинке. Ако нисте тражили ресетовање лозинке, занемарите ову поруку.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Кликните следећу везу за ресетовање лозинке. Ако нисте тражили ресетовање лозинке, занемарите ову поруку.",
    "Reset your password" : "Ресетуј лозинку",
    "No translation provider available" : "Није доступан ниједан пружалац услиге превода",
    "Could not detect language" : "Не може да се детектује језик",
    "Unable to translate" : "Не може да се преведе",
    "Nextcloud Server" : "Nextcloud сервер",
    "Some of your link shares have been removed" : "Неке везе дељења су уклоњене",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Услед безбедоносних мера, морали смо да уклонимо неке од ваших веза дељења. Кликните везу за више информација.",
    "The user limit of this instance is reached." : "Достигнута је граница броја корисника ове инстанце.",
    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Унестите ваш кључ претплате у апликацију за подршку да бисте увећали границу броја корисника. На овај начин добијате још погодности које нуди Nextcloud Enterprise и топло се препоручује за рад у компанијама.",
    "Learn more ↗" : "Сазнајте више ↗",
    "Preparing update" : "Припремам ажурирање",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Корак поправке:",
    "Repair info:" : "Инфо о поправци:",
    "Repair warning:" : "Упозорење о поправци:",
    "Repair error:" : "Грешка поправке:",
    "Please use the command line updater because updating via the browser is disabled in your config.php." : "Молимо вас да користите алат за ажурирање из командне линије јер је ажурирање из прегледача искључено у вашем config.php.",
    "Turned on maintenance mode" : "Режим одржавања укључен",
    "Turned off maintenance mode" : "Режим одржавања искључен",
    "Maintenance mode is kept active" : "Режим одржавања се држи активним",
    "Updating database schema" : "Освежава се шема базе података",
    "Updated database" : "База података ажурирана",
    "Update app \"%s\" from App Store" : "Ажурирај апликацију „%s” из Продавнице апликација",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Провера да ли шема базе података за %s може бити ажурирана (ово може да потраје, у зависности од величине базе)",
    "Updated \"%1$s\" to %2$s" : "„%1$s“ ажурирано на %2$s",
    "Set log level to debug" : "Постави ниво дневника на дебаговање",
    "Reset log level" : "Ресетуј ниво уписа у дневник",
    "Starting code integrity check" : "Почињем проверу интегритета кода",
    "Finished code integrity check" : "Завршена провера интегритета кода",
    "%s (incompatible)" : "%s (некомпатибилан)",
    "The following apps have been disabled: %s" : "Следеће апликације су искључене: %s",
    "Already up to date" : "Већ је ажурна",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Сервер није правилно подешен за синхронизацију фајлова. Изгледа да је ВебДАВ сучеље покварено.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Ваш веб сервер није исправно подешен да разреши „{url}”. Више информација можете да пронађете у {linkstart}документацији ↗{linkend}.",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Ваш веб сервер није исправно подешен да разреши „{url}”. Ово је највероватније везано за конфигурацију веб сервера која није ажурирана тако да директно достави овај фолдер. Молимо вас да упоредите своју конфигурацију са оном испорученом уз програм и поново испишите правила у „.htaccess” за Apache, или приложену у документацији за Nginx на његовој {linkstart}страници документације ↗{linkend}. На Nginx су обично линије које почињу са \"location ~\" оне које треба да се преправе.",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Ваш веб сервер није исправно подешен да испоручи .woff2 фајлове. Ово је обично проблем са Nginx конфигурацијом. За Nextcloud 15 је неопходно да се направе измене у конфигурацији како би могли да се испоруче и .woff2 фајлови. Упоредите своју Nginx конфигурацију са препорученом конфигурацијом у нашој {linkstart}документацији ↗{linkend}.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP изгледа није исправно подешен да дохвата променљиве окружења. Тест са getenv(\"PATH\") враћа празну листу као одговор.",
    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Молимо вас да погледате напомене у вези са PHP конфигурацијом и PHP конфигурацијом вашег сервера у {linkstart}документацији за инсталирање, ↗{linkend} поготово ако користите php-fpm.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Омогућена је конфигурација само за читање. То спречава постављање неке конфигурације преко веб-интерфејса. Осим тога, фајлу мора бити ручно омогућено уписивање код сваког освежавања.",
    "You have not set or verified your email server configuration, yet. Please head over to the {mailSettingsStart}Basic settings{mailSettingsEnd} in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "Још увек нисте поставили или потврдили своју конфигурацију е-поште. Молимо вас пређите на {mailSettingsStart}Основна подешавања{mailSettingsEnd}  да је поставите. Након тога, употребите дугме „Пошаљи имејл” испод форме и потврдите своја подешавања.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "База података није покренута са „READ COMMITTED“ нивоом изолације трансакција. Ово може изазвати проблеме ако се више различитих акција изврши у паралели.",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "Недостаје PHP модул „fileinfo“. Препоручујемо да га укључите да бисте добили најбоље резултате с откривањем MIME типова фајлова.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "Закључавање фајла по трансакцијама је искључено, то може да доведе до проблема са стањима утркивања. Укључите „filelocking.enabled” у config.php да спречите ове проблеме. За више информација погледајте {linkstart}документацију. ↗{linkend}",
    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"{suggestedOverwriteCliURL}\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "Молимо вас да обезбедите да је опција „overwrite.cli.url” у config.php фајлу постављена на URL који ваши корисници углавном користе за приступ овој Nextcloud инстанци. Предлог: „{suggestedOverwriteCliURL}”. У супротном може доћи до проблема са генерисањем URL преко cron. (Мада је могуће да предложени URL није URL који ваши корисници углавном користе да приступе овој Nextcloud инстанци. У сваком случају је најбоље да се ово провери.)",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "Ваша инсталација нема постављен подразумевани телефонски позивни број. Ово је неопходно за проверу бројева телефона у подешавањима профила без кода земље. Ако желите да дозволите бројеве без кода земље, молимо вас да у свој конфигурациони фајл додате „default_phone_region” са одговарајућим {linkstart}ISO 3166-1 кодом ↗{linkend} региона.",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Није било могуће да се изврши крон задатак путем интерфејса командне линије. Појавиле су се следеће техничке грешке:",
    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "Последњи посао у позадини се извршавао {relativeTime}. Изгледа да нешто није у реду. {linkstart}Проверите подешавања посла у позадини ↗{linkend}.",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {linkstart}https://nextcloud.com/enterprise{linkend}." : "Ово је Nextcloud који је изградила заједница и није подржан. Узевши у обзир величину инстанце, перформансе, поузданост и скалабилност не могу да се гарантују. Брза обавештења су ограничена да би се спречило загушење нашег бесплатног сервиса. Сазнајте више о предностима Nextcloud Enterprise на {linkstart}https://nextcloud.com/enterprise{linkend}.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Овај сервер нема функционалну интернет конекцију: више крајњих тачака није доступно. Ово значи да неће радити неке могућности као што су качење спољних складишта, обавештења о ажурирањима или инсталација апликација треће стране. Приступање фајловима споља и слање обавештења е-поштом исто тако може да не ради. Ако желите да уживате у свим могућностима, обезбедите везу овог сервера са интернетом.",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Нисте подесили меморијски кеш. Да бисте побољшали перформансе, подесите меморијски кеш ако је доступан. Више информација можете да пронађете у {linkstart}документацији ↗{linkend}.",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "PHP није пронашао погодан извор случајности, а то се не пропоручује из разлога безбедности. Више информација можете да пронађете у {linkstart}документацији ↗{linkend}.",
    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "Тренутно користите {version} верзију PHP-а. Чим Ваша дистрибуција почне да је подржава, надоградите PHP верзију и искористите сва {linkstart}безбедоносна ажурирања и побољшања перформанси које обезбеђује PHP група ↗{linkend}.",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Или су подешавања заглавља реверсног проксија неисправна, или Nextcloud инстанци приступате кроз прокси којем се верује. Ако то није случај, ово је безбедносни проблем који нападачу може дозволити да лажира своју IP адресу коју види Nextcloud. Више информација о овоме можете да пронађете у {linkstart}документацији ↗{linkend}.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Као дистрибуирани кеш је подешен memcached, али је инсталиран погрешни PHP модул \"memcache\". \\OC\\Memcache\\Memcached подржава само \"memcached\" а не и \"memcache\". Погледајте {linkstart}memcached вики у вези са оба ова модула ↗{linkend}.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Неки фајлови нису прошли проверу интегритета. Више информација о томе како овај проблем може да се реши можете да пронађете у {linkstart1}документацији ↗{linkend}. ({linkstart2}Листа неисправних фајлова…{linkend} / {linkstart3}Поново скенирај…{linkend})",
    "The PHP OPcache module is not properly configured. See the {linkstart}documentation ↗{linkend} for more information." : "PHP модул OPcache није исправно подешен. За више информација погледајте {linkstart}документацију ↗{linkend}.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP функција „set_time_limit“ није доступна. Ово може да узрокује да се скрипте закоче у сред извршавања, и тако покваре инсталацију. Препоручује се да омогућите ову функцију.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Ваша PHP инсталација нема подршку за FreeType. Ово ће довести до неисправних профилних слика и неисправног интерфејса за подешавања.",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Индекс „{indexName}“ недостаје у табели „{tableName}“.",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "У бази недостају поједини индекси. Због тога што додавање индекса на великим табелама може доста да потраје, индекси се не додају аутоматски. Покретањем „occ db:add-missing-indices“, индекси који недостају ће бити додати ручно док је инстанца покренута. Једном када су индекси додати, упити над тим табелама ће обично бити много бржи.",
    "Missing primary key on table \"{tableName}\"." : "У табели „{tableName}” недостаје примарни кључ.",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "У бази података недостају неки примарни кључеви. Услед тога што операција додавања примарних кључева у велике табеле може да потраје, они нису додати аутоматски. Извршавањем команде „occ db:add-missing-primary-keys” би се ти примарни кључеви ручно додали док инстанца несментано ради.",
    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Недостаје опциона колона „{columnName}“ у табели „{tableName}“.",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "У бази недостају неке опционе колоне. Пошто додавање колона на великим табелама може да потраје, нису додате аутоматски, а пошто су и опционе. Покретањем „occ db:add-missing-columns“ , додаћете ове колоне за време рада инстанце. Када се ове колоне додају, неке функционалности можда буду брже или употребљивије.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Овој инстанци недостају неки препоручени PHP модули. Препоручује се да их инсталирате због побољшања перформанси и за бољу компатибилност.",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "PHP модул „imagick” није укључен мада је укључена апликација за теме. Да би генерисање favicon сличице функционисало како треба, морате да инсталирате и укључите овај модул.",
    "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "PHP модули „gmp” и/или „bcmath” нису укључени. Ако користите WebAuthn аутентификацију без лозинки, ови модули су обавезни.",
    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page ↗{linkend} about this." : "Изгледа да покрећете 32-битну PHP верзију. За правилно извршавање Nextcloud захтева 64-битну верзију. Молимо вас да ажурирате свој оперативни систем и PHP на 64-бита! За више детаља прочитајте {linkstart}страницу документације ↗{linkend} која се бави овим проблемом.",
    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Модул php-imagick у овој инстанци нема подршку за SVG. У циљу боље компатибилности, препоручује се да га инсталирате.",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Неке колоне у бази података нису претворене у big int тип. Пошто у великим табелама промена типа колоне може доста да потраје, оне нису аутоматски промењене. Извршавањем команде „occ db:convert-filecache-bigint” ће се применити ове преостале измене. Ова операција се мора урадити док инстанца не ради. За више детаља, прочитајте {linkstart}страницу документације о овоме ↗{linkend}.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "Тренутно се као база података користи SQLite. За веће инсталације, препоручујемо да промените базу података.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "Ово се нарочито порепоручује ако се користи клијент програм у графичком окружењу за синхронизацију.",
    "To migrate to another database use the command line tool: \"occ db:convert-type\", or see the {linkstart}documentation ↗{linkend}." : "За прелазак на другу базу података, користите алат командне линије:  „occ db:convert-type”, или погледајте {linkstart}документацију ↗{linkend}.",
    "The PHP memory limit is below the recommended value of 512MB." : "Меморијско ограничење за ПХП је испод препоручене вредности од 512MB.",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Власник неких апликативних директоријума је корисник који није исти као и корисник по којим ради веб сервер. Ово је могуће ако су се апликације инсталирале ручно. Проверите привилегије над следећим апликативним директоријумима:",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Као база података се користи MySQL, али не подржава 4-бајтне карактере. Препоручује се да укључите подршку за 4-бајтне карактере у MySQL да би се у именима фајлова и коментарима, на пример, без проблема обрадили 4-бајтни карактери (као што су емођи). За више детаља прочитајте {linkstart}страницу документације о овоме ↗{linkend}.",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Ова инстанца користи S3 базирано чување података за основно складиште. Отпремљени фајлови се привремено чувају на серверу и препоручује се да имате доступно бар 50 GB слободног простора у PHP привременом директоријуму. Погледајте дневник за више детаља око путања и слободном простору. Да бисте ово променили или побољшали, измените привремени директоријум у php.ini фајлу или направите више слободног места на тренутној путањи.",
    "The temporary directory of this instance points to an either non-existing or non-writable directory." : "Привремени директоријум ове инстанце показује или на непостојећи, или на директоријум у који не може да се уписује.",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "Вашој инстанци приступате преко безбедне везе, међутим, ова инстанца генерише небезбедне URL адресе. Ово највероватније значи да се налазите иза реверсног проксија и да променљиве подешавања преписивања нису исправно постављене. Молимо вас да прочитате {linkstart}страницу документације у вези овога ↗{linkend}.",
    "Error occurred while checking server setup" : "Дошло је до грешке при провери поставки сервера",
    "For more details see the {linkstart}documentation ↗{linkend}." : "За више детаља погледајте {linkstart}документацију ↗{linkend}.",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Вашем директоријуму са подацима и фајловама вероватно може да се приступи са интернета. Фајл .htaccess не функционише. Изричито препоручујемо да свој веб сервер подесите тако да се забрани приступ директоријуму са подацима, или да да преместите ван кореног директоријума докумената вашег веб сервера.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP заглавље „{header}“ није подешено као „{expected}“. Ово потенцијално угрожава безбедност и приватност и препоручује се да подесите ову поставку.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "HTTP заглавље „{header}“ није подешено као „{expected}“. Неке функције можда неће радити исправно, па препоручује се да подесите ову поставку.",
    "The \"{header}\" HTTP header does not contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP заглавље „{header}“ не садржи „{expected}“. Ово потенцијално угрожава безбедност и приватност, па се препоручује да исправно подесите ово подешавање.",
    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "HTTP заглавље „{header}” није постављено на „{val1}”, „{val2}”, „{val3}”, „{val4}” или „{val5}”. На тај начин могу да процуре информације у упућивачу. Погледајте {linkstart}W3C препоруку ↗{linkend}.",
    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "„Strict-Transport-Security” HTTP заглавље није постављене барем на „{seconds}” секунди. За додатну сигурност, препоручује се да укључите HSTS као што је описано у {linkstart}безбедносним саветима ↗{linkend}.",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}." : "Сајту се небезбедно пристипа преко HTTP протокола. Снажно се препоручује да свој сервер поставите тако да уместо њега захтева HTTPS протокол, као што је описано у {linkstart}безбедносним саветима ↗{linkend}.",
    "unknown text" : "непознат текст",
    "Hello world!" : "Здраво свете!",
    "sunny" : "сунчано",
    "Hello {name}, the weather is {weather}" : "Здраво {name}, време је {weather}",
    "Hello {name}" : "Здраво {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Ово су резултати Ваше претраге<script>alert(1)</script></strong>",
    "new" : "ново",
    "_download %n file_::_download %n files_" : ["преузми %n фајл","преузми %n фајла","преузми %n фајлова"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Ажурирање је у току. У неким окружењима, напуштање ове стране може да прекине овај процес.",
    "Update to {version}" : "Ажурирај на {version}",
    "An error occurred." : "Дошло је до грешке.",
    "Please reload the page." : "Поново учитајте страницу.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Ажурирање није успело. За више информација <a href=\"{url}\">погледајте нашу објаву на форуму</a> која обрађује ову тему.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Ажурирање није успело. Пријавите овај проблем <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Некстклауд заједници</a>.",
    "Continue to {productName}" : "Наставите на {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Ажурирање је било успешно. Преусмеравате се на {productName} за %n секунду.","Ажурирање је било успешно. Преусмеравате се на {productName} за %n секунде.","Ажурирање је било успешно. Преусмеравате се на {productName} за  %n секунди."],
    "More apps" : "Још апликација",
    "Currently open" : "Тренутно отворена",
    "_{count} notification_::_{count} notifications_" : ["{count} обавештење","{count} обавештења","{count} обавештења"],
    "Log in" : "Пријава",
    "Logging in …" : "Пријављивање …",
    "Server side authentication failed!" : "Потврда идентитета на серверу није успела!",
    "Please contact your administrator." : "Контактирајте вашег администратора.",
    "An internal error occurred." : "Догодила се унутрашња грешка. ",
    "Please try again or contact your administrator." : "Покушајте поново или контактирајте вашег администратора.",
    "Account name or email" : "Име налога или е-адреса",
    "Password" : "Лозинка",
    "Log in to {productName}" : "Пријавите се на {productName}",
    "Wrong username or password." : "Погрешно корисничко име или лозинка",
    "User disabled" : "Корисник искључен",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Приметили смо више неисправних покушаја пријава са Ваше IP адресе. Следећа пријава ће бити могућа тек за 30 секунди.",
    "Username or email" : "Корисничко име или е-адреса",
    "Your account is not setup for passwordless login." : "Ваш налог није подешен за пријаву без лозинке.",
    "Browser not supported" : "Веб читач није подржан",
    "Passwordless authentication is not supported in your browser." : "Ваш веб читач не подржава пријављивање без лозинке.",
    "Your connection is not secure" : "Ваша веза није безбедна",
    "Passwordless authentication is only available over a secure connection." : "Пријављивање без лозинке је доступно само на безбедним конекцијама.",
    "Reset password" : "Ресетуј лозинку",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "Ако овај налог постоји, на његову и-мејл адресу је послата порука за ресетовање лозинке. Ако је не примите, потврдите своју и-мејл адресу и/или назив налога, проверите фолдере за нежељену пошту, или потражите помоћ свог локалног администратора.",
    "Couldn't send reset email. Please contact your administrator." : "Не могу да пошаљем поруку за ресетовање. Контактирајте администратора.",
    "Password cannot be changed. Please contact your administrator." : "Лозинка не може да се промени. Молимо вас контактирајте администратора.",
    "Back to login" : "Назад на пријаву",
    "New password" : "Нова лозинка",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Ваши фајлови су шифровани. Не постоји ниједан начин да се Ваши подаци поврате ако се лозинка сад ресетује. Уколико нисте сигурни шта да радите, контактирајте Вашег администратора пре него што наставите. Да ли стварно желите да наставите?",
    "I know what I'm doing" : "Знам шта радим",
    "Resetting password" : "Ресетујем лозинку",
    "Recommended apps" : "Препоручене апликације",
    "Loading apps …" : "Учитавам апликације…",
    "Could not fetch list of apps from the App Store." : "Листа апликација није могла да се преузме са продавнице апликација.",
    "Installing apps …" : "Инсталирам апликације…",
    "App download or installation failed" : "Скидање или инсталирање апликације није успело",
    "Cannot install this app because it is not compatible" : "Ова апликација не може да се инсталира јер није компатибилна",
    "Cannot install this app" : "Ова апликација не може да се инсталира",
    "Skip" : "Preskoči",
    "Install recommended apps" : "Инсталирајте препоручене апликације",
    "Schedule work & meetings, synced with all your devices." : "Закажите посао & састанке, синхронизовано на све ваше уређаје.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Држите колеге и пријатеље на једном месту без цурења приватних података.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Једноставна е-мејл апликација која се лепо интегрише са Фајловима, Контактима и Календаром.",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Ћаскање, видео позиви, дељење екрана, састанци на интернету & веб конференције – на десктоп рачунару и преко мобилних апликација.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Заједнички документи, табеле и презентације, изграђени на Collabora Online.",
    "Distraction free note taking app." : "Апликација за вођење бележака без ометања.",
    "Search contacts" : "Претрага контакта",
    "Forgot password?" : "Заборавили сте лозинку?",
    "Log in with a device" : "Пријава са уређајем",
    "Back" : "Назад",
    "Login form is disabled." : "Форма за пријаву је искључена.",
    "Edit Profile" : "Уреди профил",
    "The headline and about sections will show up here" : "Овде ће се појавити насловна линија и одељак „о”",
    "You have not added any info yet" : "Још увек нисте додали никакве информације",
    "{user} has not added any info yet" : "{user} још увек није унео никакве информације",
    "Error opening the user status modal, try hard refreshing the page" : "Грешка приликом отварања модалног прозора за статус корисника, покушајте да освежите страну уз брисање кеша",
    "Search starts once you start typing and results may be reached with the arrow keys" : "Претрага започиње чим почнете да куцате и до резултата долазите курсорским тастерима",
    "Reset search" : "Ресетуј претрагу",
    "Start search" : "Покрени претрагу",
    "Search for {name} only" : "Тражи само за {name}",
    "Start typing to search" : "Почните да куцате да бисте претраживали",
    "Loading more results …" : "Учитавам још резултата…",
    "Load more results" : "Учитај још резултата",
    "Search" : "Претражи",
    "No results for {query}" : "Нема резултата за упит {query}",
    "An error occurred while searching for {type}" : "Десила се грешка приликом тражења за {type}",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Унесите {minSearchLength} или више карактера да бисте претраживали","Унесите {minSearchLength} или више карактера да бисте претраживали","Унесите {minSearchLength} или више карактера да бисте претраживали"],
    "This browser is not supported" : "Овај веб читач није подржан",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Ваш веб читач није подржан. Молимо вас да га ажурирате на новију верзију, или да инсталирате подржани читач.",
    "Continue with this unsupported browser" : "Настави са овим неподржаним читачем",
    "Supported versions" : "Подржане верзије",
    "{name} version {version} and above" : "{name} верзија {version} и новије",
    "Open settings menu" : "Отвори мени подешавања",
    "Settings menu" : "Мени подешавања",
    "Search {types} …" : "Претражи {types}…",
    "Settings" : "Поставке",
    "Avatar of {fullName}" : "Аватар корисника {fullName}",
    "Could not load your contacts" : "Не могу да учитам Ваше контакте",
    "Search contacts …" : "Претражи контакте ...",
    "No contacts found" : "Контакти нису нађени",
    "Show all contacts …" : "Прикажи све контакте ...",
    "Install the Contacts app" : "Инсталирај апликацију Контакти",
    "Loading your contacts …" : "Учитавам контакте ...",
    "Looking for {term} …" : "Тражим {term} …",
    "No" : "Не",
    "Yes" : "Да",
    "No files in here" : "Овде нема фајлова",
    "New folder" : "Нова фасцикла",
    "No more subfolders in here" : "Нема више потфасцикли",
    "Name" : "назив",
    "Size" : "величина",
    "Modified" : "измењено",
    "\"{name}\" is an invalid file name." : "„{name}“ није исправан назив фајла.",
    "File name cannot be empty." : "Назив фајла не може бити празан.",
    "\"/\" is not allowed inside a file name." : "\"/\" није дозвољен каракетер у имену фајла.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" није дозвољени тип фајла",
    "{newName} already exists" : "{newName} већ постоји",
    "Choose" : "Изаберите",
    "Copy" : "Копирај",
    "Move" : "Премести",
    "Error loading file picker template: {error}" : "Грешка при учитавању шаблона бирача фајлова: {error}",
    "OK" : "У реду",
    "Error loading message template: {error}" : "Грешка при учитавању шаблона поруке: {error}",
    "read-only" : "само-за-читање",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} сукоб фајлова","{count} сукоба фајлова","{count} сукоба фајлова"],
    "One file conflict" : "Један сукоб фајлова",
    "New Files" : "Нови фајлови",
    "Already existing files" : "Постојећи фајлови",
    "Which files do you want to keep?" : "Које фајлове желите да задржите?",
    "If you select both versions, the copied file will have a number added to its name." : "Ако изаберете обе верзије, копираном фајлу ће бити додат број у називу.",
    "Cancel" : "Одустани",
    "Continue" : "Настави",
    "(all selected)" : "(све изабрано)",
    "({count} selected)" : "(изабрано: {count})",
    "Error loading file exists template" : "Грешка при учитавању шаблона „Фајл постоји“",
    "Show list view" : "Prikaži prikaz liste",
    "Show grid view" : "Prikaži prikaz mreže",
    "Pending" : "На чекању",
    "Home" : "Почетна",
    "Copy to {folder}" : "Копирај у {folder}",
    "Move to {folder}" : "Премести у {folder}",
    "Saving …" : "Чувам…",
    "Authentication required" : "Неопходна провера идентитета",
    "This action requires you to confirm your password" : "Ова радња захтева да потврдите лозинку",
    "Confirm" : "Потврди",
    "Failed to authenticate, try again" : "Неуспешна провера идентитета, покушајте поново",
    "seconds ago" : "пре пар секунди",
    "Connection to server lost" : "Изгубљена је веза са сервером",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Грешка приликом учитавања стране, пробам поново за %n секунду","Грешка приликом учитавања стране, пробам поново за %n секунде","Грешка приликом учитавања стране, пробам поново за %n секунди"],
    "Add to a project" : "Додај у пројекат",
    "Show details" : "Прикажи детаље",
    "Hide details" : "Сакриј детаље",
    "Rename project" : "Преименуј пројекат",
    "Failed to rename the project" : "Грешка при преименовању пројекат",
    "Failed to create a project" : "Грешка при креирању пројекта",
    "Failed to add the item to the project" : "Грешка приликом додавања ставке у пројекат",
    "Connect items to a project to make them easier to find" : "Повежите ставке у пројекат да Вам буде лакше да их нађете",
    "Type to search for existing projects" : "Крените да куцате да тражите постојеће пројекте",
    "New in" : "Ново у",
    "View changelog" : "Погледајте дневник измена",
    "Very weak password" : "Веома слаба лозинка",
    "Weak password" : "Слаба лозинка",
    "So-so password" : "Осредња лозинка",
    "Good password" : "Добра лозинка",
    "Strong password" : "Јака лозинка",
    "No action available" : "Нема доступне радње",
    "Error fetching contact actions" : "Грешка приликом дохватања акција над контактима",
    "Close \"{dialogTitle}\" dialog" : "Затвори дијалог „{dialogTitle}”",
    "Non-existing tag #{tag}" : "Непостојећа ознака #{tag}",
    "Restricted" : "Ограничена",
    "Invisible" : "Невидљива",
    "Delete" : "Обриши",
    "Rename" : "Преименуј",
    "Collaborative tags" : "Oзнаке сарадње",
    "No tags found" : "Ознаке нису нађене",
    "Personal" : "Лично",
    "Users" : "Корисници",
    "Apps" : "Апликације",
    "Admin" : "Администрација",
    "Help" : "Помоћ",
    "Access forbidden" : "Забрањен приступ",
    "Profile not found" : "Није пронађен профил",
    "The profile does not exist." : "Профил не постоји.",
    "Back to %s" : "Назад на %s",
    "Page not found" : "Страна није нађена",
    "The page could not be found on the server." : "На серверу не може да се пронађе ова страница.",
    "Too many requests" : "Превише захтева",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Са ваше мреже долази превише захтева. Покушајте поново касније или контактирајте администратора уколико је ово нека грешка.",
    "Error" : "Грешка",
    "Previous" : "Претходно",
    "Internal Server Error" : "Унутрашња грешка сервера",
    "The server was unable to complete your request." : "Сервер не може да обради Ваш захтев.",
    "If this happens again, please send the technical details below to the server administrator." : "Ако се ово понови, пошаљите техниче детаље испод администратору овог сервера.",
    "More details can be found in the server log." : "Више детаља се може наћи у дневнику сервера.",
    "Technical details" : "Технички детаљи",
    "Remote Address: %s" : "Удаљена адреса: %s",
    "Request ID: %s" : "ИД захтева: %s",
    "Type: %s" : "Тип: %s",
    "Code: %s" : "Кôд: %s",
    "Message: %s" : "Порука: %s",
    "File: %s" : "Фајл: %s",
    "Line: %s" : "Линија: %s",
    "Trace" : "Траг",
    "Security warning" : "Безбедносно упозорење",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Ваш директоријум са подацима и фајлови су вероватно доступни са интернета јер .htaccess не ради.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "За информације како да правилно подесите Ваш сервер, погледајте <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">документацију</a>.",
    "Create an <strong>admin account</strong>" : "Направи <strong>административни налог</strong>",
    "Username" : "Корисничко име",
    "Show password" : "Прикажи лозинку",
    "Toggle password visibility" : "Укључи/искључи видљивост лозинке",
    "Storage & database" : "Складиште и база података",
    "Data folder" : "Фасцикла за податке",
    "Configure the database" : "Подешавање базе",
    "Only %s is available." : "Само %s је доступна.",
    "Install and activate additional PHP modules to choose other database types." : "Инсталирајте и активирајте додатне „ПХП“ модуле за одабир других база података.",
    "For more details check out the documentation." : "За више детаља погледајте документацију.",
    "Database user" : "Корисник базе",
    "Database password" : "Лозинка базе",
    "Database name" : "Назив базе",
    "Database tablespace" : "Радни простор базе података",
    "Database host" : "Домаћин базе",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Наведите и број порта у имену домаћина (нпр. localhost:5432).",
    "Performance warning" : "Упозорење о перформансама",
    "You chose SQLite as database." : "Одабрали сте SQLite за базу података.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite треба да се користи само за најмање инстанце или за инстанце за развој. За продукцију, препоручујемо други тип база података.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Коришћење SQLite базе података нарочите није препоручљиво ако користите клијенте за синхронизацију фајлова.",
    "Install" : "Инсталирај",
    "Installing …" : "Инсталирам ...",
    "Need help?" : "Треба вам помоћ?",
    "See the documentation" : "Погледајте документацију",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Делује као да покушавате да реинсталирате Nextcloud. Међутим, фајл CAN_INSTALL фали из конфигурационог директоријума, Молимо креирајте фајл CAN_INSTALL у овом директоријуму да бисте наставили.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Не могу да уклоним CAN_INSTALL из конфигурационе фасцикле. Уклоните овај фајл ручно.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Ова апликација захтева Јава скрипт за исправан рад. {linkstart}Омогућите Јава скрипт{linkend} и поново учитајте страницу.",
    "Skip to main content" : "Прескочи на главни садржај",
    "Skip to navigation of app" : "Прескочи на навигацију апликације",
    "Get your own free account" : "Узмите бесплатан налог",
    "Go to %s" : "Иди на %s",
    "Confirm your password" : "Потврдите лозинку",
    "Connect to your account" : "Повежите се на Ваш налог",
    "Please log in before granting %1$s access to your %2$s account." : "Прво се пријавите пре него што одобрите привилегију %1$s приступ Вашем налогу %2$s.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Ако не покушавате да подесите нови уређај или апликацију, неко покушава да Вас превари да му дате приступ Вашим подацима. У том случају, не настављајте и контактирајте администратора Вашег система.",
    "App token" : "Апликативни жетон",
    "Grant access" : "Одобри приступ",
    "Alternative log in using app token" : "Алтернативна пријава коришћењем апликативног жетона",
    "Account access" : "Приступ налогу",
    "Currently logged in as %1$s (%2$s)." : "Тренутно пријављен као %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Управо ћете одобрити %1$s приступ Вашем %2$s налогу.",
    "Account connected" : "Налог повезан",
    "Your client should now be connected!" : "Ваш клијент сада треба да је повезан!",
    "You can close this window." : "Можете затворити овај прозор.",
    "This share is password-protected" : "Ово дељење је заштићено лозинком",
    "The password is wrong or expired. Please try again or request a new one." : "Лозинка је погрешна или је истекла. Молимо вас да покушате поново, или затражите нову.",
    "Please type in your email address to request a temporary password" : "Молимо вас унесите своју и-мејл адресу да затражите привремену лозинку",
    "Email address" : "Адреса е-поште",
    "Password sent!" : "Лозинка је послата!",
    "You are not authorized to request a password for this share" : "Немате право да за овај дељени ресурс тражите лозинку",
    "Two-factor authentication" : "Двофакторска провера идентитета",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Повећана сигурност је омогућена за овај налог. Одаберите други фактор за проверу идентитета:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Није могуће учитати ниједан метод двофакторске провере идентитета. Контактирајте администратора.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Двофакторска провера идентитета је захтевана, али није још подешена на Вашем налогу. Контактирајте администратора за помоћ.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Двофакторска провера идентитета је захтевана, али није још подешена на Вашем налогу. Контактирајте администратора да подеси двофакторску проверу идентитета.",
    "Set up two-factor authentication" : "Подеси двофакторску проверу идентитета",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Двофакторска провера идентитета је захтевана, али није још подешена на Вашем налогу. Или употребите Ваше резервне кôдове, или контактирајте администратора за помоћ.",
    "Use backup code" : "Користите резервни кôд",
    "Cancel login" : "Откажи пријављивање",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Повећана сигурност је захтевана за овај налог. Одаберите провајдера којег желите да подесите:",
    "Error while validating your second factor" : "Грешка при провери Вашег другог фактора",
    "Access through untrusted domain" : "Приступ кроз небезбедни домен",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Контактирајте Вашег администратора. Ако сте Ви администратор, измените \"trusted_domains\" подешавање у config/config.php као у примеру config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Више информација о томе како ово подесити можете да нађете у %1$s документацији%2$s.",
    "App update required" : "Потребно ажурирање апликације",
    "%1$s will be updated to version %2$s" : "%1$s ће бити ажуриран на верзију %2$s",
    "The following apps will be updated:" : "Следеће апликације ће бити ажуриране:",
    "These incompatible apps will be disabled:" : "Ове неусаглашене апликације биће онемогућене:",
    "The theme %s has been disabled." : "Тема %s је онемогућена.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Проверите да ли сте направили резервну копију фасцикли са подешавањима и подацима пре него што наставите.",
    "Start update" : "Почни ажурирање",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Да избегнете прекорачење времена одзива на већим инсталацијама, можете покренути следећу команду у инсталационом директоријуму:",
    "Detailed logs" : "Детаљни дневници",
    "Update needed" : "Потребно је ажурирање",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Молимо користите ажурирање из конзоле пошто имате велики сервер са више од 50 корисника.",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Ажурирање урадите преко командне линије јер је аутоматско ажурирање онемогућено у config.php.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "За помоћ, погледајте <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">документацију</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Свестан сам да уколико наставим ажурирање преко веб сучеља, постоји ризик да захтеву истекне време за извршење и да то може да изазове губитак података, али имам резервну копију и знам како да је повратим у случају грешке.",
    "Upgrade via web on my own risk" : "Надогради преко веба на сопствену одговорност",
    "Maintenance mode" : "Режим одржавања",
    "This %s instance is currently in maintenance mode, which may take a while." : "Овај %s је тренутно у режиму одржавања што може потрајати.",
    "This page will refresh itself when the instance is available again." : "Ова страница ће се сама освежити када инстанца постане поново доступна.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Контактирајте администратора ако се порука понавља или се неочекивано појавила.",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Ово Nextcloud издање заједнице није подржано и инстант обавештења нису доступна.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Проверавам табелу %s",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "Ово је Nextcloud који је изградила заједница и није подржан. Узевши у обзир величину инстанце, перформансе, поузданост и скалабилност не могу да се гарантују. Брза обавештења су искључена да би се спречило загушење нашег бесплатног сервиса. Сазнајте више о предностима Nextcloud Enterprise на nextcloud.com/enterprise.",
    "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23 је последње издање које подржава PHP 7.3. Nextcloud 24 захтева барем PHP 7.4.",
    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP заглавље „{header}“ не садржи „{expected}“. Ово потенцијално угрожава безбедност и приватност и препоручује се да подесите ову поставку.",
    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "На е-мејл адресу овог налога је послата порука за ресетовање лозинке. Ако је не примите, проверите фолдере за нежељену пошту/отпад или потражите помоћ од свог локалног администратора.",
    "If it is not there ask your local administrator." : "Ако није ни тамо, контактирајте вашег администратора.",
    "Collaboratively edit office documents." : "Уређујте документа заједно.",
    "Local document editing back-end used by the Collabora Online app." : "Позадински мотор за локално уређивање докумената који користи Collabora апликацију.",
    "restricted" : "ограничено",
    "invisible" : "невидљиво",
    "File not found" : "Фајл није нађен",
    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Овај документ није нађен на серверу. Можда је дељење избрисано или му је истекао рок трајања?",
    "More" : "Још",
    "More apps menu" : "Мени још апликација",
    "Contacts" : "Контакти",
    "Contacts menu" : "Мени контаката",
    "Setup two-factor authentication" : "Подеси двофакторску проверу идентитета",
    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page about this ↗{linkend}." : "Изгледа да покрећете 32-битну PHP верзију. За правилно извршавање Nextcloud захтева 64-битну верзију. Молимо вас да ажурирате свој оперативни систем и PHP на 64-бита! За више детаља прочитајте {linkstart}страницу документације која се бави овим проблемом ↗{linkend}.",
    "Press enter to start searching" : "Притисните ентер да започнете претрагу",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Молимо вас да користите алат за ажурирање из командне линије јер је ажурирање из прегледача искључено у вашем config.php."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
